@@ -127,7 +127,7 @@ heatmapGO <- function(db,
 
     h1 <- suppressWarnings(draw(
       Heatmap(data,
-        name = "-log10(Adj. P-value + 1)", col = col_fun,
+        name = "-log10(Adj. P-value)", col = col_fun,
         row_names_gp = gpar(fontsize = 10),
         show_row_dend = F, show_column_names = F,
         show_column_dend = F, row_gap = unit(55, "cm"),
@@ -147,12 +147,12 @@ heatmapGO <- function(db,
     ))
   }
 
-  if (which_list != "not_from_DE") path_save <- file.path(outfolder, "ComparisonHeatmap", which_list)
-  if (which_list == "not_from_DE") path_save <- file.path(outfolder, "ComparisonHeatmap")
+  if (which_list != "not_from_DE") path_save <- file.path(outfolder, "comparison_heatmap", which_list)
+  if (which_list == "not_from_DE") path_save <- file.path(outfolder, "comparison_heatmap")
 
   if (!dir.exists(path_save)) dir.create(path_save, recursive = T)
 
-  name_save <- paste0(path_save, "_", db, "_min", min_term_per_row, ".png")
+  name_save <- paste0(path_save, "/heatmap_", db, "_min", min_term_per_row, ".png")
 
   saving <- function(data, path_save) {
     if (nrow(data) > 35) {
